# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/41_cell.ipynb.

# %% auto 0
__all__ = ['ALL', 'ESC', 'ENDO', 'GLIA', 'MESO', 'HEMA', 'NEURAL', 'PREGERM', 'CARDIAC', 'SOMITES', 'NEURAL_PROG', 'NEURAL_CREST',
           'TROPHOBLAST', 'RADIAL_GLIA']

# %% ../nbs/41_cell.ipynb 5
ALL = 'all'

ESC = 'esc'

ENDO = 'endo'
GLIA = 'glia'

MESO = 'meso'
HEMA = 'hema'

NEURAL = 'neural'

PREGERM = 'pregerm'
CARDIAC = 'cardiac'
SOMITES = 'somites'

NEURAL_PROG = f'{NEURAL}_prog'
NEURAL_CREST = f'{NEURAL}_crest'

TROPHOBLAST = 'trophblast'
RADIAL_GLIA = f'radial_{GLIA}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/52_tree.ipynb.

# %% auto 0
__all__ = ['BASE', 'LEAF', 'TREE', 'ROOT', 'NODE']

# %% ../nbs/52_tree.ipynb 6
BASE = 'base'
LEAF = 'leaf'
TREE = 'tree'
ROOT = 'root'
NODE = 'node'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/102_text.ipynb.

# %% auto 0
__all__ = ['WIDTH', 'BREAK_LONG_WORDS']

# %% ../nbs/102_text.ipynb 4
WIDTH = 'width'
BREAK_LONG_WORDS = 'break_long_words'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/20_plot.ipynb.

# %% auto 0
__all__ = ['PLOT', 'PROJ', 'IS2D', 'LABEL', 'TITLE', 'SUPTITLE', 'CMAP', 'COLOR', 'COLOR_MAP', 'EDGECOLOR', 'FACECOLOR',
           'LINECOLOR', 'TAB', 'TABCLN', 'XKCD', 'XKCDCLN', 'PROJECTION', 'LIGHT', 'DARK', 'DEEP', 'MUTED', 'PASTEL',
           'BRIGHT', 'COLORBLIND', 'HLS', 'HUSL', 'MAKO', 'CREST', 'FLARE', 'MAGMA', 'ROCKT', 'VIRIDIS']

# %% ../nbs/20_plot.ipynb 4
from nchr import CLN
from .args import IS

# %% ../nbs/20_plot.ipynb 7
PLOT = 'plot'

PROJ = 'proj'

IS2D = f'{IS}2d'
IS2D = f'{IS}3d'

# %% ../nbs/20_plot.ipynb 9
LABEL = 'label'

TITLE = 'title'
SUPTITLE = f'sup{TITLE}'

# %% ../nbs/20_plot.ipynb 11
CMAP = 'cmap'

COLOR = 'color'
COLOR_MAP = f'{COLOR}_map'

EDGECOLOR = f'edge{COLOR}'
FACECOLOR = f'face{COLOR}'
LINECOLOR = f'line{COLOR}'

# %% ../nbs/20_plot.ipynb 13
TAB = 'tab'
TABCLN = f'{TAB}{CLN}'

XKCD = 'xkcd'
XKCDCLN = f'{XKCD}{CLN}'

# %% ../nbs/20_plot.ipynb 15
PROJECTION = f'{PROJ}ection'

# %% ../nbs/20_plot.ipynb 18
LIGHT = 'light'
DARK = 'dark'
_R = '_r'

# %% ../nbs/20_plot.ipynb 20
DEEP = 'deep'
MUTED = 'muted'
PASTEL = 'pastel'
BRIGHT = 'bright'
DARK = 'dark'
COLORBLIND = 'colorblind'

# %% ../nbs/20_plot.ipynb 22
HLS = 'hls'
HUSL = 'husl'

# %% ../nbs/20_plot.ipynb 24
MAKO = 'mako'
CREST = 'crest'
FLARE = 'flare'
MAGMA = 'magma'
ROCKT = 'rocket'
VIRIDIS = 'viridis'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'AUTO', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'SCORE', 'ZSCORE', 'GZSCORE', 'L1', 'L2', 'LOG', 'LOG1P', 'OT',
           'MMD', 'PSEUDO', 'PSEUDOTIME', 'DPT_PSEUDOTIME', 'PCS', 'COMP', 'LOAD', 'PROJ', 'COMPONENTS', 'LOADINGS',
           'PROJECTION', 'PROJECTIONS', 'SVD', 'LANDMARK', 'N_SVD', 'N_LANDMARK', 'SEED', 'RANDOM_STATE', 'GRAPH', 'G',
           'P', 'A', 'K', 'KMEANS', 'JOBS', 'NJOBS', 'N_JOBS', 'CENT', 'CENTS', 'CENTROIDS', 'EUCLIDEAN', 'MAP', 'DIFF',
           'DIFFUSION', 'AFFINITY', 'DISTANCE', 'DIFFUSION_MAP', 'DIFFUSION_AFFINITY']

# %% ../nbs/31_mthd.ipynb 4
from nchr import U1
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'

AUTO = 'auto'

UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

SCORE = 'score'
ZSCORE = f'z{SCORE}'
GZSCORE = f'g{ZSCORE}'


L1 = 'l1'
L2 = 'l2'
LOG = 'log'
LOG1P = f'{LOG}1p'

OT = 'ot'
MMD = 'mmd'

# %% ../nbs/31_mthd.ipynb 7
PSEUDO = 'pseudo'
PSEUDOTIME = f'{PSEUDO}{TIME}'
DPT_PSEUDOTIME = f'{DPT}{U1}{PSEUDOTIME}'

# %% ../nbs/31_mthd.ipynb 8
PCS = 'pcs'

COMP = 'comp'
LOAD = 'load'
PROJ = 'proj'

COMPONENTS = f'{COMP}onents'
LOADINGS = f'{LOAD}ings'

PROJECTION = f'{PROJ}ection'
PROJECTIONS = f'{PROJECTION}s'

# %% ../nbs/31_mthd.ipynb 9
SVD = 'svd'
LANDMARK = 'landmark'

N_SVD = f'n_{SVD}'
N_LANDMARK = f'n_{LANDMARK}'

# %% ../nbs/31_mthd.ipynb 10
SEED = 'seed'
RANDOM_STATE = 'random_state'

# %% ../nbs/31_mthd.ipynb 11
GRAPH = 'graph'
G = 'g'
P = 'p'
A = 'a'
K = 'k'

KMEANS = f'{K}means'

# %% ../nbs/31_mthd.ipynb 12
JOBS = 'jobs'
NJOBS = f'n{JOBS}'
N_JOBS = f'n_{JOBS}'

# %% ../nbs/31_mthd.ipynb 13
CENT = 'cent'
CENTS = f'{CENT}s'
CENTROIDS = f'{CENT}roids'

# %% ../nbs/31_mthd.ipynb 14
EUCLIDEAN = 'euclidean'

# %% ../nbs/31_mthd.ipynb 15
MAP = 'map'
DIFF = 'diff'
DIFFUSION = f'{DIFF}usion'
AFFINITY = 'affinity'
DISTANCE = 'distance'
DIFFUSION_MAP = f'{DIFFUSION}{U1}{MAP}'
DIFFUSION_AFFINITY = f'{DIFFUSION}{U1}{AFFINITY}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/61_tens.ipynb.

# %% auto 0
__all__ = ['DETACH', 'DEVICE', 'CUDA', 'MPS', 'CPU', 'IPU', 'XPU', 'TPU', 'MKLDNN', 'OPENGL', 'OPENCL', 'VULKAN', 'IDEEP', 'HIP',
           'VE', 'FPGA', 'ORT', 'XLA', 'LAZY', 'META', 'HPU', 'PRIVATEUSEONE', 'NCCL', 'CUDNN', 'NVIDIA', 'CLONE',
           'NUMPY', 'ACC', 'ACCEL', 'ACCELERATORS', 'EYE', 'DIRAC', 'ZEROS', 'NORMAL', 'SPARSE', 'UNIFORM', 'CONSTANT',
           'ORTHOGONAL', 'XAVIER', 'KAIMING', 'XAVIER_NORMAL', 'KAIMING_NORMAL', 'XAVIER_UNIFORM', 'ELU', 'LOG', 'MIN',
           'MAX', 'HARD', 'SOFT', 'PLUS', 'RELU', 'TANH', 'LEAKY', 'SWISH', 'SHRINK', 'SIGMOID', 'MULTI', 'HEAD', 'ATT',
           'ATTENTION', 'HARDTANH', 'HARDSWISH', 'HARDSHRINK', 'HARDSIGMOID', 'SOFTMIN', 'SOFTMAX', 'SOFTPLUS',
           'SOFTMAX2D', 'SOFTSHRINK', 'LEAKYRELU', 'LOGSOFTMAX', 'LOGSIGMOID', 'MULTIHEADATTENTION', 'GLU', 'SELU',
           'CELU', 'GELU', 'PRELU', 'SILU', 'MISH', 'TANHSHRINK', 'THRESHOLD', 'ADAPTIVELOGSOFTMAXWITHLOSS', 'TCHW',
           'THWC', 'NUM', 'PAD', 'PROJ', 'LAYER', 'LAYERS', 'SIZE', 'INPUT', 'HIDDEN', 'OUTPUT', 'INPUT_SIZE',
           'HIDDEN_SIZE', 'OUTPUT_SIZE', 'NUM_LAYERS', 'BIAS', 'BATCH', 'BATCH_SIZE', 'BATCH_FIRST', 'DROPOUT',
           'BIDIRECTIONAL', 'PROJ_SIZE', 'NONLINEARITY', 'IS2D', 'INIT', 'NINIT', 'N_INIT', 'IS_BUILT', 'IS_AVAILABLE']

# %% ../nbs/61_tens.ipynb 4
from .args import IS

# %% ../nbs/61_tens.ipynb 6
DETACH = 'detach'
DEVICE = 'device'

# %% ../nbs/61_tens.ipynb 8
CUDA = 'cuda'
MPS = 'mps'
CPU = 'cpu'
IPU = 'ipu'
XPU = 'xpu'
TPU = 'tpu'
MKLDNN = 'mkldnn'
OPENGL = 'opengl'
OPENCL = 'opencl'
VULKAN = 'vulkan'
IDEEP = 'ideep'
HIP = 'hip'
VE = 've'
FPGA = 'fpga'
ORT = 'ort'
XLA = 'xla'
LAZY = 'lazy'
META = 'meta'
HPU = 'hpu'
PRIVATEUSEONE = 'privateuseone'

# %% ../nbs/61_tens.ipynb 10
NCCL = 'nccl'
CUDNN = 'cudnn'
NVIDIA = 'nvidia'

# %% ../nbs/61_tens.ipynb 12
CLONE = 'clone'
NUMPY = 'numpy'

# %% ../nbs/61_tens.ipynb 14
ACC = 'acc'
ACCEL = f'{ACC}el'
ACCELERATORS = f'{ACCEL}erators'

# %% ../nbs/61_tens.ipynb 17
EYE = 'eye'
DIRAC = 'dirac'
ZEROS = 'zeros'
NORMAL =  'normal'
SPARSE = 'sparse'
UNIFORM = 'uniform'
CONSTANT = 'constant'
ORTHOGONAL = 'orthogonal'

XAVIER = 'xavier'
KAIMING = 'kaiming'

XAVIER_NORMAL = f'{XAVIER}_{NORMAL}'
KAIMING_NORMAL = f'{KAIMING}_{NORMAL}'
XAVIER_UNIFORM = f'{XAVIER}_{UNIFORM}'

# %% ../nbs/61_tens.ipynb 19
ELU = 'elu'
LOG = 'log'

MIN = 'min'
MAX = 'max'
HARD = 'hard'
SOFT = 'soft'
PLUS = 'plus'

RELU = f'r{ELU}'
TANH = 'tanh'

LEAKY = 'leaky'
SWISH = 'swish'

SHRINK = 'shrink'
SIGMOID = 'sigmoid'

MULTI = 'multi'
HEAD = 'head'

ATT = 'att'
ATTENTION = f'{ATT}ention'

# %% ../nbs/61_tens.ipynb 20
HARDTANH = f'{HARD}{TANH}'
HARDSWISH = f'{HARD}{SWISH}'
HARDSHRINK = f'{HARD}{SHRINK}'
HARDSIGMOID = f'{HARD}{SIGMOID}'

SOFTMIN = f'{SOFT}{MIN}'
SOFTMAX = f'{SOFT}{MAX}'
SOFTPLUS = f'{SOFT}{PLUS}'
SOFTMAX2D = f'{SOFTMAX}2d'
SOFTSHRINK = f'{SOFT}{SHRINK}'

LEAKYRELU = f'{LEAKY}{RELU}'

LOGSOFTMAX = f'{LOG}{SOFTMAX}'
LOGSIGMOID = f'{LOG}{SIGMOID}'

MULTIHEADATTENTION = f'{MULTI}{HEAD}{ATTENTION}'

GLU = 'glu'

SELU = f's{ELU}'
CELU = f'c{ELU}'
GELU = f'g{ELU}'
PRELU = f'p{RELU}'

SILU = 'silu'
MISH = 'mish'

TANHSHRINK = f'{TANH}{SHRINK}'

THRESHOLD = 'threshold'

ADAPTIVELOGSOFTMAXWITHLOSS = f'adaptive{LOGSOFTMAX}withloss'

# %% ../nbs/61_tens.ipynb 22
TCHW = 'tchw'
THWC = 'thwc'

# %% ../nbs/61_tens.ipynb 24
NUM = 'num'

PAD = 'pad'

PROJ = 'proj'
LAYER = 'layer'
LAYERS = f'{LAYER}s'

SIZE = 'size'
INPUT = 'input'
HIDDEN = 'hidden'
OUTPUT = 'output'
INPUT_SIZE = f'{INPUT}_{SIZE}'
HIDDEN_SIZE = f'{HIDDEN}_{SIZE}'
OUTPUT_SIZE = f'{OUTPUT}_{SIZE}'

NUM_LAYERS = f'{NUM}_{LAYERS}'
BIAS = 'bias'
BATCH = 'batch'
BATCH_SIZE = f'{BATCH}_{SIZE}'
BATCH_FIRST = f'{BATCH}_first'


DROPOUT = 'dropout'
BIDIRECTIONAL = 'bidirectional'
PROJ_SIZE = f'{PROJ}_{SIZE}'
NONLINEARITY = 'nonlinearity'

# %% ../nbs/61_tens.ipynb 26
IS2D = f'{IS}2d'
IS2D = f'{IS}3d'

# %% ../nbs/61_tens.ipynb 27
INIT = 'init'
NINIT = f'n{INIT}'
N_INIT = f'n_{INIT}'

# %% ../nbs/61_tens.ipynb 28
IS_BUILT = 'is_built'
IS_AVAILABLE = 'is_available'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IS', 'DF', 'DS', 'DX', 'ALT', 'HAS', 'GET', 'GOT', 'SET', 'GEN', 'CON', 'DEC', 'IDX', 'SEP', 'FMT', 'KEY', 'POS',
           'CAT', 'ERR', 'RET', 'MSG', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF', 'KEYS',
           'PREP', 'PROP', 'DECO', 'LINK', 'PATH', 'PROPS', 'ATTRS', 'TYPES', 'FUNCS', 'HUSH', 'SELF', 'QUIET', 'RAISE',
           'FAILQ', 'SPEC', 'SPECS', 'ANTI', 'PTTN', 'PATTERN', 'ANTI_PTTN', 'DEBUG', 'PRINT', 'VALUE', 'GUARD',
           'ERROR', 'COLOR', 'LABEL', 'TITLE', 'NBINS', 'CUTOFF', 'MIXINS', 'UNIQUE', 'HIDDEN', 'IGNORE', 'ORIGIN',
           'DEFAULT', 'INPLACE', 'VERBOSE', 'REVERSE', 'EXCLUDE', 'SPECIAL', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV',
           'SYMB', 'CONS', 'FMTFUNC', 'MOD', 'PKG', 'ARG', 'KWS', 'VAR', 'KWDS', 'ARGS', 'KWARGS', 'VARS', 'VARG',
           'VKWS', 'VARGS', 'VKWDS', 'VKWARGS', 'DROP', 'DROPNONE', 'BEG', 'END', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX',
           'PREFIX', 'SUFFIX', 'STRS', 'SUNDER', 'DUNDER', 'MANGLED', 'PRIVATE', 'CHAR', 'PROPERTY', 'OVERWRITE',
           'OVERWRITABLE', 'ALTS', 'ALTER', 'ALTERNATES']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IS = 'is'

# %% ../nbs/02_args.ipynb 7
DF = 'df'
DS = 'ds'
DX = 'dx'

# %% ../nbs/02_args.ipynb 8
ALT = 'alt'
HAS = 'has'
GET = 'get'
GOT = 'got'
SET = 'set'

# %% ../nbs/02_args.ipynb 9
GEN = 'gen'
CON = 'con'
DEC = 'dec'

# %% ../nbs/02_args.ipynb 10
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'
KEY = 'key'
POS = 'pos'
CAT = 'cat'

# %% ../nbs/02_args.ipynb 11
ERR = 'err'
RET = 'ret'
MSG = 'msg'

# %% ../nbs/02_args.ipynb 12
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'
KEYS = 'keys'
PREP = 'prep'
PROP = 'prop'
DECO = 'deco'


# %% ../nbs/02_args.ipynb 13
LINK = 'link'
PATH = 'path'

# %% ../nbs/02_args.ipynb 14
PROPS = f'{PROP}s'
ATTRS = f'{ATTR}s'
TYPES = f'{TYPE}s'
FUNCS = f'{FUNC}s'

# %% ../nbs/02_args.ipynb 15
HUSH = 'hush'
SELF = 'self'

QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 16
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 17
ANTI = 'anti'
PTTN = 'pttn'
PATTERN = 'pattern'

ANTI_PTTN = f'{ANTI}_{PTTN}'

# %% ../nbs/02_args.ipynb 18
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'
GUARD = 'guard'
ERROR = 'error'

COLOR = 'color'
LABEL = 'label'
TITLE = 'title'

NBINS = 'nbins'

# %% ../nbs/02_args.ipynb 19
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 20
HIDDEN = 'hidden'
IGNORE = 'ignore'
ORIGIN = 'origin'

# %% ../nbs/02_args.ipynb 21
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'
REVERSE = 'reverse'
EXCLUDE = 'exclude'
SPECIAL = 'special'

# %% ../nbs/02_args.ipynb 22
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 24
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 26
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 27
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 30
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 32
ARG = 'arg'
KWS = 'kws'
VAR = 'var'
KWDS = 'kwds'
ARGS = f'{ARG}s'
KWARGS = f'kw{ARGS}'
VARS = f'{VAR}s'
VARG = f'v{ARG}'
VKWS = f'v{KWS}'
VARGS = f'v{ARGS}'
VKWDS = f'v{KWDS}'
VKWARGS = f'v{KWARGS}'
SELF = 'self'

# %% ../nbs/02_args.ipynb 33
DROP = 'drop'
DROPNONE = f'{DROP}none'


# %% ../nbs/02_args.ipynb 35
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

PREFIX = f'pre{FIX}'
SUFFIX = f'suf{FIX}'

STRS = 'strs'

# %% ../nbs/02_args.ipynb 36
SUNDER = 'sunder'
DUNDER = 'dunder'
MANGLED = 'mangled'
PRIVATE = 'private'

# %% ../nbs/02_args.ipynb 37
CHAR = 'char'


# %% ../nbs/02_args.ipynb 39
PROP = 'prop'
PROPS = f'{PROP}s'
PROPERTY = f'{PROP}erty'

# %% ../nbs/02_args.ipynb 41
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'

# %% ../nbs/02_args.ipynb 42
ALT = 'alt'
ALTS = f'{ALT}s'
ALTER = 'alter'
ALTERNATES = f'{ALTER}nates'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/42_fmtx.ipynb.

# %% auto 0
__all__ = ['MATRIX', 'BARCODES', 'FEATURES', 'SENSITIVITY', 'FILTERED_MATRIX', 'FilteredMatrixFile']

# %% ../nbs/42_fmtx.ipynb 4
from enum import StrEnum

# %% ../nbs/42_fmtx.ipynb 5
from .biol import MATRIX, BARCODES, FEATURES, ADATA
from .exts import EXT_MTX, EXT_TSV, EXT_H5

# %% ../nbs/42_fmtx.ipynb 7
MATRIX = 'matrix'
BARCODES = 'barcodes'
FEATURES = 'features'
SENSITIVITY = 'sensitivity'
FILTERED_MATRIX = f'filtered_{MATRIX}'

# %% ../nbs/42_fmtx.ipynb 8
class FilteredMatrixFile(StrEnum):
    MATRIX = f'{MATRIX}{EXT_MTX}'
    BARCODES = f'{BARCODES}{EXT_TSV}'
    FEATURES = f'{FEATURES}{EXT_TSV}'
    ADATA = f'{ADATA}{EXT_H5}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/21_clrs.ipynb.

# %% auto 0
__all__ = ['ALICEBLUE', 'ANTIQUEWHITE', 'AQUA', 'AQUAMARINE', 'AZURE', 'B', 'BEIGE', 'BISQUE', 'BLACK', 'BLANCHEDALMOND', 'BLUE',
           'BLUEVIOLET', 'BROWN', 'BURLYWOOD', 'C', 'CADETBLUE', 'CHARTREUSE', 'CHOCOLATE', 'CORAL', 'CORNFLOWERBLUE',
           'CORNSILK', 'CRIMSON', 'CYAN', 'DARKBLUE', 'DARKCYAN', 'DARKGOLDENROD', 'DARKGRAY', 'DARKGREEN', 'DARKGREY',
           'DARKKHAKI', 'DARKMAGENTA', 'DARKOLIVEGREEN', 'DARKORANGE', 'DARKORCHID', 'DARKRED', 'DARKSALMON',
           'DARKSEAGREEN', 'DARKSLATEBLUE', 'DARKSLATEGRAY', 'DARKSLATEGREY', 'DARKTURQUOISE', 'DARKVIOLET', 'DEEPPINK',
           'DEEPSKYBLUE', 'DIMGRAY', 'DIMGREY', 'DODGERBLUE', 'FIREBRICK', 'FLORALWHITE', 'FORESTGREEN', 'FUCHSIA', 'G',
           'GAINSBORO', 'GHOSTWHITE', 'GOLD', 'GOLDENROD', 'GRAY', 'GREEN', 'GREENYELLOW', 'GREY', 'HONEYDEW',
           'HOTPINK', 'INDIANRED', 'INDIGO', 'IVORY', 'K', 'KHAKI', 'LAVENDER', 'LAVENDERBLUSH', 'LAWNGREEN',
           'LEMONCHIFFON', 'LIGHTBLUE', 'LIGHTCORAL', 'LIGHTCYAN', 'LIGHTGOLDENRODYELLOW', 'LIGHTGRAY', 'LIGHTGREEN',
           'LIGHTGREY', 'LIGHTPINK', 'LIGHTSALMON', 'LIGHTSEAGREEN', 'LIGHTSKYBLUE', 'LIGHTSLATEGRAY', 'LIGHTSLATEGREY',
           'LIGHTSTEELBLUE', 'LIGHTYELLOW', 'LIME', 'LIMEGREEN', 'LINEN', 'M', 'MAGENTA', 'MAROON', 'MEDIUMAQUAMARINE',
           'MEDIUMBLUE', 'MEDIUMORCHID', 'MEDIUMPURPLE', 'MEDIUMSEAGREEN', 'MEDIUMSLATEBLUE', 'MEDIUMSPRINGGREEN',
           'MEDIUMTURQUOISE', 'MEDIUMVIOLETRED', 'MIDNIGHTBLUE', 'MINTCREAM', 'MISTYROSE', 'MOCCASIN', 'NAVAJOWHITE',
           'NAVY', 'OLDLACE', 'OLIVE', 'OLIVEDRAB', 'ORANGE', 'ORANGERED', 'ORCHID', 'PALEGOLDENROD', 'PALEGREEN',
           'PALETURQUOISE', 'PALEVIOLETRED', 'PAPAYAWHIP', 'PEACHPUFF', 'PERU', 'PINK', 'PLUM', 'POWDERBLUE', 'PURPLE',
           'R', 'REBECCAPURPLE', 'RED', 'ROSYBROWN', 'ROYALBLUE', 'SADDLEBROWN', 'SALMON', 'SANDYBROWN', 'SEAGREEN',
           'SEASHELL', 'SIENNA', 'SILVER', 'SKYBLUE', 'SLATEBLUE', 'SLATEGRAY', 'SLATEGREY', 'SNOW', 'SPRINGGREEN',
           'STEELBLUE', 'TAB_BLUE', 'TAB_BROWN', 'TAB_CYAN', 'TAB_GRAY', 'TAB_GREEN', 'TAB_OLIVE', 'TAB_ORANGE',
           'TAB_PINK', 'TAB_PURPLE', 'TAB_RED', 'TAN', 'TEAL', 'THISTLE', 'TOMATO', 'TURQUOISE', 'VIOLET', 'W', 'WHEAT',
           'WHITE', 'WHITESMOKE', 'Y', 'YELLOW', 'YELLOWGREEN']

# %% ../nbs/21_clrs.ipynb 6
ALICEBLUE            = 'aliceblue'
ANTIQUEWHITE         = 'antiquewhite'
AQUA                 = 'aqua'
AQUAMARINE           = 'aquamarine'
AZURE                = 'azure'
B                    = 'b'
BEIGE                = 'beige'
BISQUE               = 'bisque'
BLACK                = 'black'
BLANCHEDALMOND       = 'blanchedalmond'
BLUE                 = 'blue'
BLUEVIOLET           = 'blueviolet'
BROWN                = 'brown'
BURLYWOOD            = 'burlywood'
C                    = 'c'
CADETBLUE            = 'cadetblue'
CHARTREUSE           = 'chartreuse'
CHOCOLATE            = 'chocolate'
CORAL                = 'coral'
CORNFLOWERBLUE       = 'cornflowerblue'
CORNSILK             = 'cornsilk'
CRIMSON              = 'crimson'
CYAN                 = 'cyan'
DARKBLUE             = 'darkblue'
DARKCYAN             = 'darkcyan'
DARKGOLDENROD        = 'darkgoldenrod'
DARKGRAY             = 'darkgray'
DARKGREEN            = 'darkgreen'
DARKGREY             = 'darkgrey'
DARKKHAKI            = 'darkkhaki'
DARKMAGENTA          = 'darkmagenta'
DARKOLIVEGREEN       = 'darkolivegreen'
DARKORANGE           = 'darkorange'
DARKORCHID           = 'darkorchid'
DARKRED              = 'darkred'
DARKSALMON           = 'darksalmon'
DARKSEAGREEN         = 'darkseagreen'
DARKSLATEBLUE        = 'darkslateblue'
DARKSLATEGRAY        = 'darkslategray'
DARKSLATEGREY        = 'darkslategrey'
DARKTURQUOISE        = 'darkturquoise'
DARKVIOLET           = 'darkviolet'
DEEPPINK             = 'deeppink'
DEEPSKYBLUE          = 'deepskyblue'
DIMGRAY              = 'dimgray'
DIMGREY              = 'dimgrey'
DODGERBLUE           = 'dodgerblue'
FIREBRICK            = 'firebrick'
FLORALWHITE          = 'floralwhite'
FORESTGREEN          = 'forestgreen'
FUCHSIA              = 'fuchsia'
G                    = 'g'
GAINSBORO            = 'gainsboro'
GHOSTWHITE           = 'ghostwhite'
GOLD                 = 'gold'
GOLDENROD            = 'goldenrod'
GRAY                 = 'gray'
GREEN                = 'green'
GREENYELLOW          = 'greenyellow'
GREY                 = 'grey'
HONEYDEW             = 'honeydew'
HOTPINK              = 'hotpink'
INDIANRED            = 'indianred'
INDIGO               = 'indigo'
IVORY                = 'ivory'
K                    = 'k'
KHAKI                = 'khaki'
LAVENDER             = 'lavender'
LAVENDERBLUSH        = 'lavenderblush'
LAWNGREEN            = 'lawngreen'
LEMONCHIFFON         = 'lemonchiffon'
LIGHTBLUE            = 'lightblue'
LIGHTCORAL           = 'lightcoral'
LIGHTCYAN            = 'lightcyan'
LIGHTGOLDENRODYELLOW = 'lightgoldenrodyellow'
LIGHTGRAY            = 'lightgray'
LIGHTGREEN           = 'lightgreen'
LIGHTGREY            = 'lightgrey'
LIGHTPINK            = 'lightpink'
LIGHTSALMON          = 'lightsalmon'
LIGHTSEAGREEN        = 'lightseagreen'
LIGHTSKYBLUE         = 'lightskyblue'
LIGHTSLATEGRAY       = 'lightslategray'
LIGHTSLATEGREY       = 'lightslategrey'
LIGHTSTEELBLUE       = 'lightsteelblue'
LIGHTYELLOW          = 'lightyellow'
LIME                 = 'lime'
LIMEGREEN            = 'limegreen'
LINEN                = 'linen'
M                    = 'm'
MAGENTA              = 'magenta'
MAROON               = 'maroon'
MEDIUMAQUAMARINE     = 'mediumaquamarine'
MEDIUMBLUE           = 'mediumblue'
MEDIUMORCHID         = 'mediumorchid'
MEDIUMPURPLE         = 'mediumpurple'
MEDIUMSEAGREEN       = 'mediumseagreen'
MEDIUMSLATEBLUE      = 'mediumslateblue'
MEDIUMSPRINGGREEN    = 'mediumspringgreen'
MEDIUMTURQUOISE      = 'mediumturquoise'
MEDIUMVIOLETRED      = 'mediumvioletred'
MIDNIGHTBLUE         = 'midnightblue'
MINTCREAM            = 'mintcream'
MISTYROSE            = 'mistyrose'
MOCCASIN             = 'moccasin'
NAVAJOWHITE          = 'navajowhite'
NAVY                 = 'navy'
OLDLACE              = 'oldlace'
OLIVE                = 'olive'
OLIVEDRAB            = 'olivedrab'
ORANGE               = 'orange'
ORANGERED            = 'orangered'
ORCHID               = 'orchid'
PALEGOLDENROD        = 'palegoldenrod'
PALEGREEN            = 'palegreen'
PALETURQUOISE        = 'paleturquoise'
PALEVIOLETRED        = 'palevioletred'
PAPAYAWHIP           = 'papayawhip'
PEACHPUFF            = 'peachpuff'
PERU                 = 'peru'
PINK                 = 'pink'
PLUM                 = 'plum'
POWDERBLUE           = 'powderblue'
PURPLE               = 'purple'
R                    = 'r'
REBECCAPURPLE        = 'rebeccapurple'
RED                  = 'red'
ROSYBROWN            = 'rosybrown'
ROYALBLUE            = 'royalblue'
SADDLEBROWN          = 'saddlebrown'
SALMON               = 'salmon'
SANDYBROWN           = 'sandybrown'
SEAGREEN             = 'seagreen'
SEASHELL             = 'seashell'
SIENNA               = 'sienna'
SILVER               = 'silver'
SKYBLUE              = 'skyblue'
SLATEBLUE            = 'slateblue'
SLATEGRAY            = 'slategray'
SLATEGREY            = 'slategrey'
SNOW                 = 'snow'
SPRINGGREEN          = 'springgreen'
STEELBLUE            = 'steelblue'
TAB_BLUE             = 'tab:blue'
TAB_BROWN            = 'tab:brown'
TAB_CYAN             = 'tab:cyan'
TAB_GRAY             = 'tab:gray'
TAB_GREEN            = 'tab:green'
TAB_OLIVE            = 'tab:olive'
TAB_ORANGE           = 'tab:orange'
TAB_PINK             = 'tab:pink'
TAB_PURPLE           = 'tab:purple'
TAB_RED              = 'tab:red'
TAN                  = 'tan'
TEAL                 = 'teal'
THISTLE              = 'thistle'
TOMATO               = 'tomato'
TURQUOISE            = 'turquoise'
VIOLET               = 'violet'
W                    = 'w'
WHEAT                = 'wheat'
WHITE                = 'white'
WHITESMOKE           = 'whitesmoke'
Y                    = 'y'
YELLOW               = 'yellow'
YELLOWGREEN          = 'yellowgreen'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/10_ncls.ipynb.

# %% auto 0
__all__ = ['CLS', 'KLS', 'SUB', 'CLASS', 'KLASS', 'SUBCLASS', 'CLSVARS', 'CLSNAME', 'KLSVARS', 'KLSNAME', 'SUBVARS', 'SUBNAME',
           'GEN', 'CON', 'DEC', 'RAW', 'DUCK', 'META', 'GUARD', 'TYPEGUARD', 'NAMESPACE', 'GENERATOR', 'CONSTRUCT',
           'DECORATOR', 'BASE', 'BASES', 'RETURN', 'ASSET', 'AREPR', 'DEFAULT', 'IMPORTED', 'SYSTEM', 'SYSTEMS', 'DCT',
           'NON', 'SIG']

# %% ../nbs/10_ncls.ipynb 5
CLS = 'cls'
KLS = 'kls'
SUB = 'sub'

CLASS = 'class'
KLASS = 'klass'
SUBCLASS = f'{SUB}class'

CLSVARS = f'{CLS}vars'
CLSNAME = f'{CLS}name'

KLSVARS = f'{KLS}vars'
KLSNAME = f'{KLS}name'

SUBVARS = f'{SUB}vars'
SUBNAME = f'{SUB}name'

# %% ../nbs/10_ncls.ipynb 6
GEN = 'gen'
CON = 'con'
DEC = 'dec'
RAW = 'raw'

DUCK = 'duck'
META = 'meta'

GUARD = 'guard'
TYPEGUARD = f'type{GUARD}'


NAMESPACE = 'namespace'
GENERATOR = 'generator'
CONSTRUCT = 'construct'
DECORATOR = 'decorator'

BASE = 'base'
BASES = f'{BASE}s'

RETURN = 'return'

ASSET = 'asset'
AREPR = 'arepr'
DEFAULT = 'default'
IMPORTED = 'imported'

# %% ../nbs/10_ncls.ipynb 7
SYSTEM = 'system'
SYSTEMS = f'{SYSTEM}s'

# %% ../nbs/10_ncls.ipynb 8
DCT = 'dct'
NON = 'non'
SIG = 'sig'
